@@ -1,5 +1,5 @@
 from .core.trainer import Trainer, TrainerArgs
 from .core.hyperparams import Hyperparams, HyperparamsSpec
-from .core.evaluator import evaluate
+from .core.evaluator import evaluate, predict_single
 from .core.auto_tuner import AutoTuner
 from .helper_funcs import train, autotune
