@@ -18,14 +18,24 @@ def evaluate(model: t.nn.Module, dataloader: DataLoader, metrics: Sequence[Metri
             batch_inputs = batch_inputs.to(DEVICE)
             batch_targets = batch_targets.to(DEVICE)
             batch_outputs = model(batch_inputs)
+
+            batch_outputs = batch_outputs.detach().cpu().numpy()
+            batch_targets = batch_targets.detach().cpu().numpy()
             if outputs is not None:
-                outputs = np.concatenate((outputs, batch_outputs.detach().cpu().numpy()))
-                targets = np.concatenate((targets, batch_targets.detach().cpu().numpy()))
+                outputs = np.concatenate((outputs, batch_outputs), axis=0)
+                targets = np.concatenate((targets, batch_targets), axis=0)
             else:
-                outputs = batch_outputs.detach().cpu().numpy()
-                targets = batch_targets.detach().cpu().numpy()
+                outputs = batch_outputs
+                targets = batch_targets
+
     mvals = []
     for metric in metrics:
         mval = np.around(metric(outputs, targets), 3)
         mvals.append(mval)
     return mvals
+
+
+def predict_single(model: t.nn.Module, x: t.Tensor):
+    batch_of_one = x.usqueeze(0)
+    y_hat = model(batch_of_one).squeeze()
+    return y_hat
